#!/usr/bin/env bash

# shell-based exodus client
#
# You will need to obtain a board id and a key. These belong in the settings
# below.
#
# You should then create a command on your board to execute this script and
# pass it the current username and the ID of the game you want to launch.
#
# Example:
#
#     /path/to/exodus_client.sh "haliphax" "lore"
#
# For a list of available games, see https://oddnetwork.org/exodus/games.md

EXODUS_BOARD="xxx"
EXODUS_KEY="xxx"
EXODUS_SSHKEY="/path/to/exodus.id_rsa"

#--- Do not edit below this line! ---

if [ $# -lt 2 ]; then
	echo "Syntax: $0 <user> <door>"
	exit 1
fi

EXODUS_USER="$1"
EXODUS_DOOR="$2"
EXODUS_NOW="$(date -u +%s)"
EXODUS_TOKEN="$(echo -n "$EXODUS_KEY$EXODUS_NOW" | sha256sum | awk '{print $1}')|$EXODUS_NOW"
EXODUS_DATA="token=$EXODUS_TOKEN&board=$EXODUS_BOARD&user=$EXODUS_USER&door=$EXODUS_DOOR"
EXODUS_TICKET="$(curl -s -k -d "$EXODUS_DATA" "https://oddnetwork.org:1984/exodus")"

if [ "$(echo -n "$EXODUS_TICKET" | awk '{print length($0)}')" != "36" ]; then
	echo $EXODUS_TICKET
	exit 1
fi

echo "Connecting to Exodus game server @ 79 Columns..."
exodus="$EXODUS_TICKET" ssh -i "$EXODUS_SSHKEY" -q -e none -o SendEnv=exodus exodus_server@oddnetwork.org
